@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 from lxml import etree
 from plone.supermodel.debug import parseinfo
 from plone.supermodel.interfaces import DEFAULT_ORDER
@@ -22,38 +21,35 @@ from zope.interface import implementer
 from zope.schema import getFields
 
 import linecache
-import six
 import sys
 import traceback
 
 
 # Exception
 class SupermodelParseError(Exception):
-
     def __init__(self, orig_exc, fname, element, tb):
         msg = str(orig_exc)
         lineno = None
-        if hasattr(orig_exc, 'lineno'):
+        if hasattr(orig_exc, "lineno"):
             lineno = orig_exc.lineno
         elif element is not None:
-            lineno = getattr(element, 'sourceline', 'unknown')
-        if fname or lineno != 'unknown':
-            msg += '\n  File "%s", line %s' % (fname or '<unknown>', lineno)
+            lineno = getattr(element, "sourceline", "unknown")
+        if fname or lineno != "unknown":
+            msg += '\n  File "{}", line {}'.format(fname or "<unknown>", lineno)
         if fname and lineno:
             line = linecache.getline(fname, lineno).strip()
-            msg += '\n    %s' % line
-        msg += '\n'
-        msg += ''.join(traceback.format_tb(tb))
-        msg += '\n'
+            msg += "\n    %s" % line
+        msg += "\n"
+        msg += "".join(traceback.format_tb(tb))
+        msg += "\n"
         self.args = [msg]
 
 
 # Helper adapters
 @implementer(ISchemaPolicy)
-class DefaultSchemaPolicy(object):
-
+class DefaultSchemaPolicy:
     def module(self, schemaName, tree):
-        return 'plone.supermodel.generated'
+        return "plone.supermodel.generated"
 
     def bases(self, schemaName, tree):
         return ()
@@ -63,9 +59,9 @@ class DefaultSchemaPolicy(object):
 
 
 # Algorithm
-def parse(source, policy=u""):
+def parse(source, policy=""):
     fname = None
-    if isinstance(source, six.string_types):
+    if isinstance(source, str):
         fname = source
 
     try:
@@ -75,8 +71,7 @@ def parse(source, policy=u""):
         # the filename and line number of the element that caused the problem.
         # Keep the original traceback so the developer can debug where the
         # problem happened.
-        raise SupermodelParseError(
-            e, fname, parseinfo.stack[-1], sys.exc_info()[2])
+        raise SupermodelParseError(e, fname, parseinfo.stack[-1], sys.exc_info()[2])
 
 
 def _parse(source, policy):
@@ -87,9 +82,7 @@ def _parse(source, policy):
     tree = etree.parse(source, parser=parser)
     root = tree.getroot()
 
-    parseinfo.i18n_domain = root.attrib.get(
-        ns('domain', prefix=I18N_NAMESPACE)
-    )
+    parseinfo.i18n_domain = root.attrib.get(ns("domain", prefix=I18N_NAMESPACE))
 
     model = Model()
 
@@ -102,25 +95,24 @@ def _parse(source, policy):
     def readField(fieldElement, schemaAttributes, fieldElements, baseFields):
 
         # Parse field attributes
-        fieldName = fieldElement.get('name')
-        fieldType = fieldElement.get('type')
+        fieldName = fieldElement.get("name")
+        fieldType = fieldElement.get("type")
 
         if fieldName is None or fieldType is None:
             raise ValueError(
-                'The attributes \'name\' and \'type\' are required for each '
-                '<field /> element'
+                "The attributes 'name' and 'type' are required for each "
+                "<field /> element"
             )
 
         handler = handlers.get(fieldType)
         if handler is None:
             handler = handlers[fieldType] = queryUtility(
-                IFieldExportImportHandler,
-                name=fieldType
+                IFieldExportImportHandler, name=fieldType
             )
             if handler is None:
                 raise ValueError(
-                    'Field type {0} specified for field {1} is not '
-                    'supported'.format(fieldType, fieldName)
+                    "Field type {} specified for field {} is not "
+                    "supported".format(fieldType, fieldName)
                 )
 
         field = handler.read(fieldElement)
@@ -137,17 +129,17 @@ def _parse(source, policy):
 
         return fieldName
 
-    for schema_element in root.findall(ns('schema')):
+    for schema_element in root.findall(ns("schema")):
         parseinfo.stack.append(schema_element)
         schemaAttributes = {}
 
-        schemaName = schema_element.get('name')
+        schemaName = schema_element.get("name")
         if schemaName is None:
-            schemaName = u""
+            schemaName = ""
 
         bases = ()
         baseFields = {}
-        based_on = schema_element.get('based-on')
+        based_on = schema_element.get("based-on")
         if based_on is not None:
             bases = tuple([resolve(dotted) for dotted in based_on.split()])
             for base_schema in bases:
@@ -156,14 +148,9 @@ def _parse(source, policy):
         fieldElements = {}
 
         # Read global fields
-        for fieldElement in schema_element.findall(ns('field')):
+        for fieldElement in schema_element.findall(ns("field")):
             parseinfo.stack.append(fieldElement)
-            readField(
-                fieldElement,
-                schemaAttributes,
-                fieldElements,
-                baseFields
-            )
+            readField(fieldElement, schemaAttributes, fieldElements, baseFields)
             parseinfo.stack.pop()
 
         # Read invariants, fieldsets and their fields
@@ -174,32 +161,23 @@ def _parse(source, policy):
         for subelement in schema_element:
             parseinfo.stack.append(subelement)
 
-            if subelement.tag == ns('field'):
-                readField(
-                    subelement,
-                    schemaAttributes,
-                    fieldElements,
-                    baseFields
-                )
+            if subelement.tag == ns("field"):
+                readField(subelement, schemaAttributes, fieldElements, baseFields)
 
-            elif subelement.tag == ns('fieldset'):
+            elif subelement.tag == ns("fieldset"):
 
-                fieldset_name = subelement.get('name')
+                fieldset_name = subelement.get("name")
                 if fieldset_name is None:
-                    raise ValueError(
-                        u'Fieldset in schema {0} has no name'.format(
-                            schemaName
-                        )
-                    )
+                    raise ValueError(f"Fieldset in schema {schemaName} has no name")
 
                 fieldset = fieldsets_by_name.get(fieldset_name)
                 if fieldset is None:
-                    fieldset_label = subelement.get('label')
-                    fieldset_description = subelement.get('description')
-                    fieldset_order = subelement.get('order')
+                    fieldset_label = subelement.get("label")
+                    fieldset_description = subelement.get("description")
+                    fieldset_order = subelement.get("order")
                     if fieldset_order is None:
                         fieldset_order = DEFAULT_ORDER
-                    elif isinstance(fieldset_order, six.string_types):
+                    elif isinstance(fieldset_order, str):
                         fieldset_order = int(fieldset_order)
                     fieldset = fieldsets_by_name[fieldset_name] = Fieldset(
                         fieldset_name,
@@ -210,25 +188,22 @@ def _parse(source, policy):
                     fieldsets_by_name[fieldset_name] = fieldset
                     fieldsets.append(fieldset)
 
-                for fieldElement in subelement.findall(ns('field')):
+                for fieldElement in subelement.findall(ns("field")):
                     parseinfo.stack.append(fieldElement)
                     parsed_fieldName = readField(
-                        fieldElement,
-                        schemaAttributes,
-                        fieldElements,
-                        baseFields
+                        fieldElement, schemaAttributes, fieldElements, baseFields
                     )
                     if parsed_fieldName:
                         fieldset.fields.append(parsed_fieldName)
                     parseinfo.stack.pop()
 
-            elif subelement.tag == ns('invariant'):
+            elif subelement.tag == ns("invariant"):
                 dotted = subelement.text
                 invariant = resolve(dotted)
                 if not IInvariant.providedBy(invariant):
                     raise ImportError(
-                        u'Invariant functions must provide '
-                        u'plone.supermodel.interfaces.IInvariant'
+                        "Invariant functions must provide "
+                        "plone.supermodel.interfaces.IInvariant"
                     )
                 invariants.append(invariant)
             parseinfo.stack.pop()
@@ -237,13 +212,13 @@ def _parse(source, policy):
             name=policy_util.name(schemaName, tree),
             bases=bases + policy_util.bases(schemaName, tree) + (Schema,),
             __module__=policy_util.module(schemaName, tree),
-            attrs=schemaAttributes
+            attrs=schemaAttributes,
         )
 
         # add invariants to schema as tagged values
         if invariants:
-            schema_invariants = schema.queryTaggedValue('invariants', [])
-            schema.setTaggedValue('invariants', schema_invariants + invariants)
+            schema_invariants = schema.queryTaggedValue("invariants", [])
+            schema.setTaggedValue("invariants", schema_invariants + invariants)
 
         # Save fieldsets
         schema.setTaggedValue(FIELDSETS_KEY, fieldsets)
@@ -253,9 +228,7 @@ def _parse(source, policy):
             for fieldName in schema:
                 if fieldName in fieldElements:
                     metadata_handler.read(
-                        fieldElements[fieldName],
-                        schema,
-                        schema[fieldName]
+                        fieldElements[fieldName], schema, schema[fieldName]
                     )
 
         for handler_name, metadata_handler in schema_metadata_handlers:
@@ -268,4 +241,4 @@ def _parse(source, policy):
     return model
 
 
-__all__ = ('parse', )
+__all__ = ("parse",)
